@@ -30,7 +30,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "4.02";
+  $VERSION= "4.03";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -86,7 +86,7 @@ package Apache2::AMFWURFLFilterMemcached;
 		$CommonLib->printLog("AMF installed is the last version");
 	}
   } else {
-	$CommonLib->printLog("AMFCheckVersione is false, AMF don't check the last version.");
+	$CommonLib->printLog("AMFCheckVersion is false, AMF don't check the last version.");
   }
   if ($ENV{ResizeImageDirectory}) {
 	  $Capability{'max_image_width'}="max_image_width";
@@ -133,9 +133,6 @@ my $memd = new Cache::Memcached {
 	  ModPerl::Util::exit();
   }
 
-
-  
-
 sub loadConfigFile {
 	my ($fileWurfl) = @_;
 	my $null="";
@@ -313,7 +310,6 @@ sub loadConfigFile {
 						$string_file =~ s/>/>\n/g;
 						my @arrayFile=split(/\n/, $string_file);
 						foreach my $line (@arrayFile) {
-						#print "$line\n";
 							$r_id=parseWURFLFile($line,$r_id);
 						}
 					} else {
@@ -397,7 +393,7 @@ sub IdentifyPCUAMethod {
 	}
   }
   if ($id_find eq "") {
-	if ($UserAgent =~ m/safari/) {
+	if ($UserAgent =~ m/safari/ && !($UserAgent =~ m/kftt/)) {
 		$id_find='safari';
 	}      
   }
